@@ -1,29 +1,11 @@
 /* -*- C++ -*-
+    This file declares the ResourceRestrictionPolicy class.
 
-This file declares the ResourceRestrictionPolicy class.
+    SPDX-FileCopyrightText: 2004-2013 Mirko Boehm <mirko@kde.org>
 
-$ Author: Mirko Boehm $
-$ Copyright: (C) 2004-2013 Mirko Boehm $
-$ Contact: mirko@kde.org
-https://www.kde.org
-http://creative-destruction.me $
+    SPDX-License-Identifier: LGPL-2.0-or-later
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-
-$Id: Job.h 32 2005-08-17 08:38:01Z mirko $
+    $Id: Job.h 32 2005-08-17 08:38:01Z mirko $
 */
 
 #ifndef RESOURCE_RESTRICTION_POLICY_H
@@ -36,7 +18,6 @@ $Id: Job.h 32 2005-08-17 08:38:01Z mirko $
 
 namespace ThreadWeaver
 {
-
 class JobInterface;
 
 /** @brief ResourceRestrictionPolicy is used to limit the number of concurrent accesses to the same resource.
